Initializes a PEAK Channel
"The handle of a PEAK Channel"
"The speed for the communication (BTR0BTR1 code)"
"Non-PnP: The type of hardware and operation mode"
"Non-PnP: The I/O address for the parallel port"
"Non-PnP: Interrupt number of the parallel port"
"A TPEAKStatus error code"
Uninitializes one or all PEAK Channels initialized by CAN_Initialize
Giving the TPEAKHandle value "PEAK_NONEBUS",
uninitialize all initialized channels
"The handle of a PEAK Channel"
"A TPEAKStatus error code"
Resets the receive and transmit queues of the PEAK Channel
A reset of the CAN controller is not performed.
"The handle of a PEAK Channel"
"A TPEAKStatus error code"
Reads a CAN message from the receive queue of a PEAK Channel
"The handle of a PEAK Channel"
"A TPEAKMsg structure buffer to store the CAN message"
"A TPEAKTimestamp structure buffer to get
the reception time of the message. If this value is not desired, this parameter
should be passed as NULL"
"A TPEAKStatus error code"
Reads a CAN message from the receive queue of a FD capable PEAK Channel
"The handle of a FD capable PEAK Channel"
"A TPEAKMsgFD structure buffer to store the CAN message"
"A TPEAKTimestampFD buffer to get
the reception time of the message. If this value is not desired, this parameter
should be passed as NULL"
"A TPEAKStatus error code"
Transmits a CAN message over a FD capable PEAK Channel
"The handle of a FD capable PEAK Channel"
"A TPEAKMsgFD buffer with the message to be sent"
"A TPEAKStatus error code"
Configures the reception filter.
The message filter will be expanded with every call to
this function. If it is desired to reset the filter, please use
the CAN_SetValue function
"The handle of a PEAK Channel"
"The lowest CAN ID to be received"
"The highest CAN ID to be received"
"Message type, Standard (11-bit identifier) or
Extended (29-bit identifier)"
"A TPEAKStatus error code"
Retrieves a PEAK Channel value
Parameters can be present or not according with the kind
of Hardware (PEAK Channel) being used. If a parameter is not available,
a PEAK_ERROR_ILLPARAMTYPE error will be returned
"The handle of a PEAK Channel"
"The TPEAKParameter parameter to get"
"Buffer for the parameter value"
"Size in bytes of the buffer"
"A TPEAKStatus error code"
Configures or sets a PEAK Channel value
Parameters can be present or not according with the kind
of Hardware (PEAK Channel) being used. If a parameter is not available,
a PEAK_ERROR_ILLPARAMTYPE error will be returned
"The handle of a PEAK Channel"
"The TPEAKParameter parameter to set"
"Buffer with the value to be set"
"Size in bytes of the buffer"
"A TPEAKStatus error code"
Returns a descriptive text of a given TPEAKStatus error
code, in any desired language
The current languages available for translation are:
Neutral (0x00), German (0x07), English (0x09), Spanish (0x0A),
Italian (0x10) and French (0x0C)
"A TPEAKStatus error code"
"Indicates a 'Primary language ID'"
"Buffer for a null terminated char array"
"A TPEAKStatus error code"
Finds a PEAK-Basic channel that matches with the given parameters
A comma separated string contained pairs of
parameter-name/value to be matched within a PEAK-Basic channel
Buffer for returning the PEAK-Basic channel,
when found
A TPEAKStatus error code